@@ -41,8 +41,7 @@ extern void py_midgard_connection_register_class(PyObject *d, gpointer pygobject
 extern void py_midgard_query_builder_register_class(PyObject *d, gpointer pygobject_type);
 extern void py_midgard_blob_register_class(PyObject *d, gpointer pygobject_type);
 extern void py_midgard_collector_register_class(PyObject *d, gpointer pygobject_type);
-extern void py_midgard_reflection_property_register_class(PyObject *d, gpointer pygobject_type);
-extern void py_midgard_object_class_register_class(PyObject *d, gpointer pygobject_type);
+extern void py_midgard_reflector_property_register_class(PyObject *d, gpointer pygobject_type);
 extern void py_midgard_replicator_register_class(PyObject *d, gpointer pygobject_type);
 extern void py_midgard_user_register_class(PyObject *d, gpointer pygobject_type);
 extern void py_midgard_dbus_register_class(PyObject *d, gpointer pygobject_type);
@@ -51,6 +50,10 @@ extern void py_midgard_storage_register_class(PyObject *d, gpointer pygobject_ty
 extern void py_midgard_view_register_class(PyObject *d, gpointer pygobject_type);
 extern void py_midgard_key_config_context_register_class(PyObject *d, gpointer pygobject_type);
 extern void py_midgard_key_config_file_context_register_class(PyObject *d, gpointer pygobject_type);
+extern void py_midgard_reflector_object_register_class(PyObject *d, gpointer pygobject_type);
+extern void py_midgard_schema_object_tree_register_class(PyObject *d, gpointer pygobject_type);
+extern void py_midgard_schema_object_factory_register_class(PyObject *d, gpointer pygobject_type);
+
 
 /* PARAMETERS */
 extern PyObject *pymidgard_object_get_parameter(PyGObject *self, PyObject *args);
