@@ -99,7 +99,7 @@ PyTypeObject G_GNUC_INTERNAL Pymidgard_metadata_Type = {
     sizeof(PyGObject),          /* tp_basicsize */
     0,                                 /* tp_itemsize */
     /* methods */
-    (destructor)_py_midgard_gobject_destructor,        /* tp_dealloc */
+    (destructor)0,        /* tp_dealloc */
     (printfunc)0,                      /* tp_print */
     (getattrfunc)0,       /* tp_getattr */
     (setattrfunc)0,       /* tp_setattr */
@@ -162,7 +162,7 @@ static int __schema_object_construct(PyGObject *self, PyObject *args, PyObject *
 
 	MidgardConnection *mgd = 
 		_py_midgard_connection_singleton_get();
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
+	MidgardObject *mobj = MIDGARD_OBJECT(self->obj);
 
 	if(!mgd)
 		PyErr_SetString(PyExc_RuntimeError, "Failed to get midgard connection");
@@ -216,7 +216,7 @@ pymidgard_object_create(PyGObject *self, PyObject *args)
 {
 	MGDOBJECT_DEBUG("create");
 
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
+	MidgardObject *mobj = MIDGARD_OBJECT(self->obj);
 
 	if(midgard_object_create(mobj))
 		Py_RETURN_TRUE;
@@ -232,7 +232,7 @@ pymidgard_object_get_by_id(PyGObject *self, PyObject *args)
 	if(!PyArg_ParseTuple(args, "i", &id))
 		return NULL;
 
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
+	MidgardObject *mobj = MIDGARD_OBJECT(self->obj);
 
 	if(midgard_object_get_by_id(mobj, id))
 		Py_RETURN_TRUE;
@@ -248,7 +248,7 @@ pymidgard_object_get_by_guid(PyGObject *self, PyObject *args)
 	if(!PyArg_ParseTuple(args, "s", &guid))
 		return NULL;
 
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
+	MidgardObject *mobj = MIDGARD_OBJECT(self->obj);
 
 	if(midgard_object_get_by_guid(mobj, guid))
 		Py_RETURN_TRUE;
@@ -263,7 +263,7 @@ pymidgard_object_update(PyGObject *self, PyObject *args)
 	if(!PyArg_ParseTuple(args, ""))
 		return NULL;
 
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
+	MidgardObject *mobj = MIDGARD_OBJECT(self->obj);
 
 	if(midgard_object_update(mobj))
 		Py_RETURN_TRUE;
@@ -275,12 +275,13 @@ static PyObject *
 pymidgard_object_delete(PyGObject *self, PyObject *args)
 {
 	MGDOBJECT_DEBUG("delete");
-	if(!PyArg_ParseTuple(args, ""))
+	gboolean check_dependents = FALSE;
+	if(!PyArg_ParseTuple(args, "|b", &check_dependents))
 		return NULL;
 
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
+	MidgardObject *mobj = MIDGARD_OBJECT(self->obj);
 
-	if(midgard_object_delete(mobj))
+	if(midgard_object_delete(mobj, check_dependents))
 		Py_RETURN_TRUE;
 
 	Py_RETURN_FALSE;
@@ -290,46 +291,13 @@ static PyObject *
 pymidgard_object_purge(PyGObject *self, PyObject *args)
 {
 	MGDOBJECT_DEBUG("purge");
-	if(!PyArg_ParseTuple(args, ""))
+	gboolean check_dependents;
+	if(!PyArg_ParseTuple(args, "|b", &check_dependents))
 		return NULL;
 
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
+	MidgardObject *mobj = MIDGARD_OBJECT(self->obj);
 
-	if(midgard_object_purge(mobj))
-		Py_RETURN_TRUE;
-
-	Py_RETURN_FALSE;
-}
-
-static PyObject *
-pymidgard_object_is_in_parent_tree(PyGObject *self, PyObject *args)
-{
-	MGDOBJECT_DEBUG("is_in_parent_tree");
-	guint root_id, id;
-
-	if(!PyArg_ParseTuple(args, "ii", &root_id, &id))
-		return NULL;
-
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
-
-	if(midgard_object_is_in_parent_tree(mobj, root_id, id))
-		Py_RETURN_TRUE;
-
-	Py_RETURN_FALSE;
-}
-
-static PyObject *
-pymidgard_object_is_in_tree(PyGObject *self, PyObject *args)
-{
-	MGDOBJECT_DEBUG("is_in_tree");
-	guint root_id, id;
-
-	if (!PyArg_ParseTuple(args, "ii", &root_id, &id))
-		return NULL;
-
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
-
-	if(midgard_object_is_in_tree(mobj, root_id, id))
+	if(midgard_object_purge(mobj, check_dependents))
 		Py_RETURN_TRUE;
 
 	Py_RETURN_FALSE;
@@ -340,7 +308,7 @@ pymidgard_object_has_dependents(PyGObject *self, PyObject *args)
 {
 	MGDOBJECT_DEBUG("has_dependents");
 	
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
+	MidgardObject *mobj = MIDGARD_OBJECT(self->obj);
 
 	if(midgard_object_has_dependents(mobj))
 		Py_RETURN_TRUE;
@@ -348,98 +316,6 @@ pymidgard_object_has_dependents(PyGObject *self, PyObject *args)
 	Py_RETURN_FALSE;
 }
 
-static PyObject *
-pymidgard_object_get_parent(PyGObject *self, PyObject *args)
-{
-	MGDOBJECT_DEBUG("get_parent");
-	if(!PyArg_ParseTuple(args, ""))
-		return NULL;
-	
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
-	MgdObject *parent = 
-		midgard_object_get_parent(mobj);
-	
-	if(parent) 
-		return Py_BuildValue("O", pygobject_new(G_OBJECT(parent)));
-	
-	Py_RETURN_NONE;
-}
-
-static PyObject *
-pymidgard_object_parent(PyGObject *self, PyObject *args)
-{
-	MGDOBJECT_DEBUG("parent");
-	if(!PyArg_ParseTuple(args, ""))
-		return NULL;
-	
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
-	const gchar *parent = 
-		midgard_object_parent(mobj);
-
-	return Py_BuildValue("s", parent);	
-}
-
-static PyObject *
-pymidgard_object_list(PyGObject *self, PyObject *args)
-{
-	MGDOBJECT_DEBUG("list");
-	if(!PyArg_ParseTuple(args, ""))
-		return NULL;
-
-	guint i = 0;
-	guint n_objects;
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
-	GObject **objects = midgard_object_list(mobj, &n_objects);
-	
-	if(objects == NULL) {
-		
-		PyObject *list = PyTuple_New(i);
-		return list;
-	}
-
-	PyObject *list = PyTuple_New(n_objects);
-
-	if(!objects) 
-		return list;
-
-	OBJECTS2LIST(objects, list);
-
-	g_free(objects);
-
-	return list;
-}
-
-static PyObject *
-pymidgard_object_list_children(PyGObject *self, PyObject *args)
-{
-	MGDOBJECT_DEBUG("list_children");
-	const gchar *childcname;
-	if(!PyArg_ParseTuple(args, "s", &childcname))
-		return NULL;
-
-	guint i = 0;
-	guint n_objects;
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
-	GObject **objects = midgard_object_list_children(mobj, childcname, &n_objects);
-
-	if(objects == NULL) {
-		
-		PyObject *list = PyTuple_New(i);
-		return list;
-	}
-
-	PyObject *list = PyTuple_New(n_objects);
-
-	if(!objects) 
-		return list;
-
-	OBJECTS2LIST(objects, list);
-
-	g_free(objects);
-
-	return list;
-}
-
 static PyObject *
 pymidgard_object_get_by_path(PyGObject *self, PyObject *args)
 {
@@ -448,7 +324,7 @@ pymidgard_object_get_by_path(PyGObject *self, PyObject *args)
 	if(!PyArg_ParseTuple(args, "s", &path))
 		return NULL;
 	
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
+	MidgardObject *mobj = MIDGARD_OBJECT(self->obj);
 
 	if(midgard_object_get_by_path(mobj, path))
 		Py_RETURN_TRUE;
@@ -464,7 +340,7 @@ pymidgard_object_approve(PyGObject *self, PyObject *args)
 	if(!PyArg_ParseTuple(args, ""))
 		return NULL;
 	
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
+	MidgardObject *mobj = MIDGARD_OBJECT(self->obj);
 
 	if(midgard_object_approve(mobj))
 		Py_RETURN_TRUE;
@@ -480,7 +356,7 @@ pymidgard_object_is_approved(PyGObject *self, PyObject *args)
 	if(!PyArg_ParseTuple(args, ""))
 		return NULL;
 	
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
+	MidgardObject *mobj = MIDGARD_OBJECT(self->obj);
 
 	if(midgard_object_is_approved(mobj))
 		Py_RETURN_TRUE;
@@ -496,7 +372,7 @@ pymidgard_object_unapprove(PyGObject *self, PyObject *args)
 	if(!PyArg_ParseTuple(args, ""))
 		return NULL;
 	
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
+	MidgardObject *mobj = MIDGARD_OBJECT(self->obj);
 
 	if(midgard_object_unapprove(mobj))
 		Py_RETURN_TRUE;
@@ -512,7 +388,7 @@ pymidgard_object_lock(PyGObject *self, PyObject *args)
 	if(!PyArg_ParseTuple(args, ""))
 		return NULL;
 	
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
+	MidgardObject *mobj = MIDGARD_OBJECT(self->obj);
 
 	if(midgard_object_lock(mobj))
 		Py_RETURN_TRUE;
@@ -528,7 +404,7 @@ pymidgard_object_is_locked(PyGObject *self, PyObject *args)
 	if(!PyArg_ParseTuple(args, ""))
 		return NULL;
 	
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
+	MidgardObject *mobj = MIDGARD_OBJECT(self->obj);
 
 	if(midgard_object_is_locked(mobj))
 		Py_RETURN_TRUE;
@@ -544,7 +420,7 @@ pymidgard_object_unlock(PyGObject *self, PyObject *args)
 	if(!PyArg_ParseTuple(args, ""))
 		return NULL;
 	
-	MgdObject *mobj = MIDGARD_OBJECT(self->obj);
+	MidgardObject *mobj = MIDGARD_OBJECT(self->obj);
 
 	if(midgard_object_unlock(mobj))
 		Py_RETURN_TRUE;
@@ -559,12 +435,6 @@ static PyMethodDef pymidgard_object_methods[] = {
 	{ "update", (PyCFunction)pymidgard_object_update, METH_VARARGS, NULL },
 	{ "delete", (PyCFunction)pymidgard_object_delete, METH_VARARGS, NULL },	
 	{ "purge", (PyCFunction)pymidgard_object_purge, METH_VARARGS, NULL },
-	{ "is_in_parent_tree", (PyCFunction)pymidgard_object_is_in_parent_tree, METH_VARARGS },
-	{ "is_in_tree", (PyCFunction)pymidgard_object_is_in_tree, METH_VARARGS },
-	{ "get_parent", (PyCFunction)pymidgard_object_get_parent, METH_VARARGS },
-	{ "parent", (PyCFunction)pymidgard_object_parent, METH_VARARGS },
-	{ "list", (PyCFunction)pymidgard_object_list, METH_VARARGS },
-	{ "list_children", (PyCFunction)pymidgard_object_list_children, METH_VARARGS },
 	{ "has_dependents", (PyCFunction)pymidgard_object_has_dependents, METH_NOARGS },
 	{ "get_by_path", (PyCFunction)pymidgard_object_get_by_path, METH_VARARGS },
 	{ "get_parameter", (PyCFunction)pymidgard_object_get_parameter, METH_VARARGS },
@@ -617,7 +487,9 @@ _py_midgard_get_object_attribute(PyObject *self, PyObject *attr)
 	g_object_get_property(object, attr_name, &pval);
 
 	PyObject *pvalue = py_midgard_pyobject_from_gvalue((const GValue*) &pval, FALSE);
-	g_value_unset(&pval);
+	if (!G_VALUE_HOLDS_OBJECT (&pval))
+		g_value_unset(&pval);
+
 	return pvalue;
 }
 
